@@ -11,8 +11,6 @@ index((aggregate_all), 4, aggregate, aggregate).
 index((free_variables), 4, aggregate, aggregate).
 index((ansi_format), 3, ansi_term, ansi_term).
 index((ansi_get_color), 2, ansi_term, ansi_term).
-index((expand_phrase), 2, apply_macros, apply_macros).
-index((expand_phrase), 4, apply_macros, apply_macros).
 index((include), 3, apply, apply).
 index((exclude), 3, apply, apply).
 index((partition), 4, apply, apply).
@@ -30,6 +28,8 @@ index((scanl), 4, apply, apply).
 index((scanl), 5, apply, apply).
 index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
+index((expand_phrase), 2, apply_macros, apply_macros).
+index((expand_phrase), 4, apply_macros, apply_macros).
 index((archive_open), 3, archive, archive).
 index((archive_open), 4, archive, archive).
 index((archive_create), 3, archive, archive).
@@ -121,6 +121,8 @@ index((set_base_module), 1, backward_compatibility, backcomp).
 index((eval_license), 0, backward_compatibility, backcomp).
 index((trie_insert_new), 3, backward_compatibility, backcomp).
 index((thread_at_exit), 1, backward_compatibility, backcomp).
+index((read_history), 6, backward_compatibility, backcomp).
+index(('$sig_atomic'), 1, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
 index((base64_encoded), 3, base64, base64).
@@ -171,13 +173,6 @@ index((open_chars_stream), 2, charsio, charsio).
 index((with_output_to_chars), 2, charsio, charsio).
 index((with_output_to_chars), 3, charsio, charsio).
 index((with_output_to_chars), 4, charsio, charsio).
-index((check_installation), 0, check_installation, check_installation).
-index((check_installation), 1, check_installation, check_installation).
-index((check_config_files), 0, check_installation, check_installation).
-index((update_config_files), 0, check_installation, check_installation).
-index((test_installation), 0, check_installation, check_installation).
-index((test_installation), 1, check_installation, check_installation).
-index((check_old_last), 0, checklast, checklast).
 index((check), 0, check, check).
 index((list_undefined), 0, check, check).
 index((list_undefined), 1, check, check).
@@ -194,6 +189,13 @@ index((list_strings), 0, check, check).
 index((list_strings), 1, check, check).
 index((list_rationals), 0, check, check).
 index((list_rationals), 1, check, check).
+index((check_installation), 0, check_installation, check_installation).
+index((check_installation), 1, check_installation, check_installation).
+index((check_config_files), 0, check_installation, check_installation).
+index((update_config_files), 0, check_installation, check_installation).
+index((test_installation), 0, check_installation, check_installation).
+index((test_installation), 1, check_installation, check_installation).
+index((check_old_last), 0, checklast, checklast).
 index((check_old_select), 0, checkselect, checkselect).
 index((format_to_codes), 3, codesio, codesio).
 index((format_to_codes), 4, codesio, codesio).
@@ -208,6 +210,7 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
+index((crypt), 2, crypt, crypt).
 index((crypto_n_random_bytes), 2, crypto, crypto).
 index((crypto_data_hash), 3, crypto, crypto).
 index((crypto_file_hash), 3, crypto, crypto).
@@ -237,7 +240,6 @@ index((crypto_name_curve), 2, crypto, crypto).
 index((crypto_curve_order), 2, crypto, crypto).
 index((crypto_curve_generator), 2, crypto, crypto).
 index((crypto_curve_scalar_mult), 4, crypto, crypto).
-index((crypt), 2, crypt, crypt).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
@@ -291,6 +293,7 @@ index((expects_dialect), 1, prolog_dialect, dialect).
 index((exists_source), 1, prolog_dialect, dialect).
 index((source_exports), 2, prolog_dialect, dialect).
 index((dicts_same_tag), 2, dicts, dicts).
+index((dict_size), 2, dicts, dicts).
 index((dict_keys), 2, dicts, dicts).
 index((dicts_same_keys), 2, dicts, dicts).
 index((dicts_to_same_keys), 3, dicts, dicts).
@@ -321,6 +324,8 @@ index((reconsult), 1, edinburgh, edinburgh).
 index((debug), 0, edinburgh, edinburgh).
 index((nodebug), 0, edinburgh, edinburgh).
 index((fileerrors), 2, edinburgh, edinburgh).
+index((edit), 1, prolog_edit, edit).
+index((edit), 0, prolog_edit, edit).
 index((el_wrap), 0, editline, editline).
 index((el_wrap), 4, editline, editline).
 index((el_wrapped), 1, editline, editline).
@@ -337,8 +342,6 @@ index((el_history_events), 2, editline, editline).
 index((el_add_history), 2, editline, editline).
 index((el_write_history), 2, editline, editline).
 index((el_read_history), 2, editline, editline).
-index((edit), 1, prolog_edit, edit).
-index((edit), 0, prolog_edit, edit).
 index((instantiation_error), 1, error, error).
 index((uninstantiation_error), 1, error, error).
 index((type_error), 2, error, error).
@@ -359,6 +362,8 @@ index((fast_write), 1, fastrw, fastrw).
 index((fast_read), 2, fastrw, fastrw).
 index((fast_write), 2, fastrw, fastrw).
 index((fast_write_to_string), 3, fastrw, fastrw).
+index((can_open_file), 2, files, files).
+index((chdir), 1, files, files).
 index((set_time_file), 3, files_ex, filesex).
 index((link_file), 3, files_ex, filesex).
 index((chmod), 2, files_ex, filesex).
@@ -370,8 +375,6 @@ index((make_directory_path), 1, files_ex, filesex).
 index((copy_directory), 2, files_ex, filesex).
 index((delete_directory_and_contents), 1, files_ex, filesex).
 index((delete_directory_contents), 1, files_ex, filesex).
-index((can_open_file), 2, files, files).
-index((chdir), 1, files, files).
 index((reset_gensym), 0, gensym, gensym).
 index((reset_gensym), 1, gensym, gensym).
 index((gensym), 2, gensym, gensym).
@@ -394,6 +397,18 @@ index((git_show), 4, git, git).
 index((git_commit_data), 3, git, git).
 index((open_hash_stream), 3, hash_stream, hash_stream).
 index((stream_hash), 2, hash_stream, hash_stream).
+index((ht_new), 1, hashtable, hashtable).
+index((ht_is_hashtable), 1, hashtable, hashtable).
+index((ht_size), 2, hashtable, hashtable).
+index((ht_put), 3, hashtable, hashtable).
+index((ht_update), 4, hashtable, hashtable).
+index((ht_put_new), 3, hashtable, hashtable).
+index((ht_put), 5, hashtable, hashtable).
+index((ht_del), 3, hashtable, hashtable).
+index((ht_get), 3, hashtable, hashtable).
+index((ht_gen), 3, hashtable, hashtable).
+index((ht_pairs), 2, hashtable, hashtable).
+index((ht_keys), 2, hashtable, hashtable).
 index((add_to_heap), 4, heaps, heaps).
 index((delete_from_heap), 4, heaps, heaps).
 index((empty_heap), 1, heaps, heaps).
@@ -410,6 +425,20 @@ index((help), 0, prolog_help, help).
 index((help), 1, prolog_help, help).
 index((apropos), 1, prolog_help, help).
 index((load_hotfixes), 1, prolog_hotfix, hotfix).
+index((incr_assert), 1, increval, increval).
+index((incr_asserta), 1, increval, increval).
+index((incr_assertz), 1, increval, increval).
+index((incr_retractall), 1, increval, increval).
+index((incr_retract), 1, increval, increval).
+index((is_incremental_subgoal), 1, increval, increval).
+index((incr_directly_depends), 2, increval, increval).
+index((incr_trans_depends), 2, increval, increval).
+index((incr_invalid_subgoals), 1, increval, increval).
+index((incr_is_invalid), 1, increval, increval).
+index((incr_invalidate_call), 1, increval, increval).
+index((incr_invalidate_calls), 1, increval, increval).
+index((incr_table_update), 0, increval, increval).
+index((incr_propagate_calls), 1, increval, increval).
 index((intercept), 3, intercept, intercept).
 index((intercept), 4, intercept, intercept).
 index((intercept_all), 4, intercept, intercept).
@@ -422,6 +451,7 @@ index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index(('$isub'), 5, isub, isub).
 index((jpl_get_default_jvm_opts), 1, jpl, jpl).
 index((jpl_set_default_jvm_opts), 1, jpl, jpl).
 index((jpl_get_actual_jvm_opts), 1, jpl, jpl).
@@ -511,8 +541,11 @@ index((same_length), 2, lists, lists).
 index((reverse), 2, lists, lists).
 index((permutation), 2, lists, lists).
 index((flatten), 2, lists, lists).
+index((clumped), 2, lists, lists).
 index((max_member), 2, lists, lists).
 index((min_member), 2, lists, lists).
+index((max_member), 3, lists, lists).
+index((min_member), 3, lists, lists).
 index((sum_list), 2, lists, lists).
 index((max_list), 2, lists, lists).
 index((min_list), 2, lists, lists).
@@ -525,6 +558,10 @@ index((subset), 2, lists, lists).
 index((subtract), 3, lists, lists).
 index((main), 0, prolog_main, main).
 index((argv_options), 3, prolog_main, main).
+index((argv_options), 4, prolog_main, main).
+index((argv_usage), 1, prolog_main, main).
+index((cli_parse_debug_options), 2, prolog_main, main).
+index((cli_enable_development_system), 0, prolog_main, main).
 index((make), 0, make, make).
 index((md5_hash), 3, md5, md5).
 index((new_memory_file), 1, memory_file, memfile).
@@ -546,6 +583,11 @@ index((memory_file_substring), 5, memory_file, memfile).
 index((memory_file_line_position), 4, memory_file, memfile).
 index((utf8_position_memory_file), 3, memory_file, memfile).
 index((in_temporary_module), 3, modules, modules).
+index((current_temporary_module), 1, modules, modules).
+index((mqi_start), 0, mqi, mqi).
+index((mqi_start), 1, mqi, mqi).
+index((mqi_stop), 1, mqi, mqi).
+index((mqi_version), 2, mqi, mqi).
 index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_node_value), 2, nb_rbtrees, nb_rbtrees).
@@ -564,6 +606,7 @@ index((occurrences_of_term), 3, occurs, occurs).
 index((occurrences_of_var), 3, occurs, occurs).
 index((sub_term), 2, occurs, occurs).
 index((sub_var), 2, occurs, occurs).
+index((sub_term_shared_variables), 3, occurs, occurs).
 index((odbc_connect), 3, odbc, odbc).
 index((odbc_driver_connect), 3, odbc, odbc).
 index((odbc_disconnect), 1, odbc, odbc).
@@ -672,6 +715,7 @@ index((re_config), 1, pcre, pcre).
 index((pdt_install_console), 0, pdt_console, pdt_console).
 index((pengine_writeln), 1, pengines_io, pengines_io).
 index((pengine_nl), 0, pengines_io, pengines_io).
+index((pengine_tab), 1, pengines_io, pengines_io).
 index((pengine_flush_output), 0, pengines_io, pengines_io).
 index((pengine_format), 1, pengines_io, pengines_io).
 index((pengine_format), 2, pengines_io, pengines_io).
@@ -716,6 +760,7 @@ index((tokenize_atom), 2, porter_stem, porter_stem).
 index((atom_to_stem_list), 2, porter_stem, porter_stem).
 index((portray_text), 1, portray_text, portray_text).
 index((set_portray_text), 2, portray_text, portray_text).
+index((set_portray_text), 3, portray_text, portray_text).
 index(('$portray_text_enabled'), 1, portray_text, portray_text).
 index((print_term), 2, prolog_pretty_print, pprint).
 index((predicate_options), 3, predicate_options, predicate_options).
@@ -764,6 +809,8 @@ index((extend_goal), 3, prolog_code, prolog_code).
 index((predicate_label), 2, prolog_code, prolog_code).
 index((predicate_sort_key), 2, prolog_code, prolog_code).
 index((is_control_goal), 1, prolog_code, prolog_code).
+index((is_predicate_indicator), 1, prolog_code, prolog_code).
+index((body_term_calls), 2, prolog_code, prolog_code).
 index((prolog_walk_code), 1, prolog_codewalk, prolog_codewalk).
 index((prolog_program_clause), 2, prolog_codewalk, prolog_codewalk).
 index((prolog_colourise_stream), 3, prolog_colour, prolog_colour).
@@ -774,6 +821,12 @@ index((syntax_colour), 2, prolog_colour, prolog_colour).
 index((syntax_message), 3, prolog_colour, prolog_colour).
 index((prolog_dump_runtime_variables), 0, prolog_config, prolog_config).
 index((apple_bundle_libdir), 1, prolog_config, prolog_config).
+index((spy), 1, prolog_debug_tools, prolog_debug).
+index((nospy), 1, prolog_debug_tools, prolog_debug).
+index((nospyall), 0, prolog_debug_tools, prolog_debug).
+index((debugging), 0, prolog_debug_tools, prolog_debug).
+index((trap), 1, prolog_debug_tools, prolog_debug).
+index((notrap), 1, prolog_debug_tools, prolog_debug).
 index((file_autoload_directives), 3, prolog_deps, prolog_deps).
 index((file_auto_import), 2, prolog_deps, prolog_deps).
 index((format_spec), 2, prolog_format, prolog_format).
@@ -799,6 +852,7 @@ index((pack_rebuild), 1, prolog_pack, prolog_pack).
 index((pack_rebuild), 0, prolog_pack, prolog_pack).
 index((pack_remove), 1, prolog_pack, prolog_pack).
 index((pack_property), 2, prolog_pack, prolog_pack).
+index((pack_attach), 2, prolog_pack, prolog_pack).
 index((pack_url_file), 2, prolog_pack, prolog_pack).
 index((prolog_server), 2, prolog_server, prolog_server).
 index((prolog_read_source_term), 4, prolog_source, prolog_source).
@@ -821,6 +875,8 @@ index((open_prolog_stream), 4, prolog_stream, prolog_stream).
 index((trace), 1, prolog_trace, prolog_trace).
 index((trace), 2, prolog_trace, prolog_trace).
 index((tracing), 2, prolog_trace, prolog_trace).
+index((notraceall), 0, prolog_trace, prolog_trace).
+index((require_prolog_version), 2, prolog_versions, prolog_versions).
 index((wrap_predicate), 4, prolog_wrap, prolog_wrap).
 index((unwrap_predicate), 2, prolog_wrap, prolog_wrap).
 index((current_predicate_wrapper), 4, prolog_wrap, prolog_wrap).
@@ -857,6 +913,10 @@ index((xref_used_class), 2, prolog_xref, prolog_xref).
 index((xref_defined_class), 3, prolog_xref, prolog_xref).
 index((protobuf_message), 2, protobufs, protobufs).
 index((protobuf_message), 3, protobufs, protobufs).
+index((protobuf_parse_from_codes), 3, protobufs, protobufs).
+index((protobuf_serialize_to_codes), 3, protobufs, protobufs).
+index((protobuf_field_is_map), 2, protobufs, protobufs).
+index((protobuf_map_pairs), 3, protobufs, protobufs).
 index((phrase_from_file), 2, pure_input, pure_input).
 index((phrase_from_file), 3, pure_input, pure_input).
 index((phrase_from_stream), 2, pure_input, pure_input).
@@ -927,9 +987,11 @@ index((maybe), 2, random, random).
 index((random_perm2), 4, random, random).
 index((random_member), 2, random, random).
 index((random_select), 3, random, random).
+index((random_subseq), 3, random, random).
 index((randseq), 3, random, random).
 index((randset), 3, random, random).
 index((random_permutation), 2, random, random).
+index((random_numlist), 4, random, random).
 index((random), 3, random, random).
 index((rb_new), 1, rbtrees, rbtrees).
 index((rb_empty), 1, rbtrees, rbtrees).
@@ -959,16 +1021,16 @@ index((ord_list_to_rbtree), 2, rbtrees, rbtrees).
 index((is_rbtree), 1, rbtrees, rbtrees).
 index((rb_size), 2, rbtrees, rbtrees).
 index((rb_in), 3, rbtrees, rbtrees).
+index((load_rdf), 2, rdf, rdf).
+index((load_rdf), 3, rdf, rdf).
+index((xml_to_rdf), 3, rdf, rdf).
+index((process_rdf), 3, rdf, rdf).
 index((rdf_diagram_from_file), 1, rdf_diagram, rdf_diagram).
 index((xml_to_plrdf), 3, rdf_parser, rdf_parser).
 index((element_to_plrdf), 3, rdf_parser, rdf_parser).
 index((make_rdf_state), 3, rdf_parser, rdf_parser).
 index((rdf_modify_state), 3, rdf_parser, rdf_parser).
 index((rdf_name_space), 1, rdf_parser, rdf_parser).
-index((load_rdf), 2, rdf, rdf).
-index((load_rdf), 3, rdf, rdf).
-index((xml_to_rdf), 3, rdf, rdf).
-index((process_rdf), 3, rdf, rdf).
 index((rdf_triples), 2, rdf_triple, rdf_triple).
 index((rdf_triples), 3, rdf_triple, rdf_triple).
 index((rdf_reset_ids), 0, rdf_triple, rdf_triple).
@@ -994,6 +1056,38 @@ index((read_file_to_terms), 3, read_util, readutil).
 index((record), 1, record, record).
 index((current_record), 2, record, record).
 index((current_record_predicate), 2, record, record).
+index((redis_server), 3, redis, redis).
+index((redis_connect), 1, redis, redis).
+index((redis_connect), 3, redis, redis).
+index((redis_disconnect), 1, redis, redis).
+index((redis_disconnect), 2, redis, redis).
+index((redis), 1, redis, redis).
+index((redis), 2, redis, redis).
+index((redis), 3, redis, redis).
+index((redis_get_list), 3, redis, redis).
+index((redis_get_list), 4, redis, redis).
+index((redis_set_list), 3, redis, redis).
+index((redis_get_hash), 3, redis, redis).
+index((redis_set_hash), 3, redis, redis).
+index((redis_scan), 3, redis, redis).
+index((redis_sscan), 4, redis, redis).
+index((redis_hscan), 4, redis, redis).
+index((redis_zscan), 4, redis, redis).
+index((redis_subscribe), 4, redis, redis).
+index((redis_subscribe), 2, redis, redis).
+index((redis_unsubscribe), 2, redis, redis).
+index((redis_current_subscription), 2, redis, redis).
+index((redis_write), 2, redis, redis).
+index((redis_read), 2, redis, redis).
+index((redis_array_dict), 3, redis, redis).
+index((redis_property), 2, redis, redis).
+index((redis_current_command), 2, redis, redis).
+index((redis_current_command), 3, redis, redis).
+index((xstream_set), 3, redis_streams, redis_streams).
+index((xadd), 4, redis_streams, redis_streams).
+index((xlisten), 3, redis_streams, redis_streams).
+index((xlisten_group), 5, redis_streams, redis_streams).
+index((xconsumer_stop), 1, redis_streams, redis_streams).
 index((rewrite_term), 2, rewrite_term, rewrite_term).
 index((rew_term_expansion), 2, rewrite_term, rewrite_term).
 index((rew_goal_expansion), 2, rewrite_term, rewrite_term).
@@ -1142,17 +1236,47 @@ index((statistics), 0, prolog_statistics, statistics).
 index((statistics), 1, prolog_statistics, statistics).
 index((thread_statistics), 2, prolog_statistics, statistics).
 index((time), 1, prolog_statistics, statistics).
+index((call_time), 2, prolog_statistics, statistics).
+index((call_time), 3, prolog_statistics, statistics).
 index((profile), 1, prolog_statistics, statistics).
 index((profile), 2, prolog_statistics, statistics).
 index((show_profile), 1, prolog_statistics, statistics).
 index((profile_data), 1, prolog_statistics, statistics).
 index((profile_procedure_data), 2, prolog_statistics, statistics).
+index((stomp_connection), 5, stomp, stomp).
+index((stomp_connection), 6, stomp, stomp).
+index((stomp_connection_property), 2, stomp, stomp).
+index((stomp_destroy_connection), 1, stomp, stomp).
+index((stomp_connect), 1, stomp, stomp).
+index((stomp_connect), 2, stomp, stomp).
+index((stomp_teardown), 1, stomp, stomp).
+index((stomp_reconnect), 1, stomp, stomp).
+index((stomp_send), 4, stomp, stomp).
+index((stomp_send_json), 4, stomp, stomp).
+index((stomp_subscribe), 4, stomp, stomp).
+index((stomp_unsubscribe), 2, stomp, stomp).
+index((stomp_ack), 2, stomp, stomp).
+index((stomp_nack), 2, stomp, stomp).
+index((stomp_ack), 3, stomp, stomp).
+index((stomp_nack), 3, stomp, stomp).
+index((stomp_transaction), 2, stomp, stomp).
+index((stomp_disconnect), 2, stomp, stomp).
+index((stomp_begin), 2, stomp, stomp).
+index((stomp_commit), 2, stomp, stomp).
+index((stomp_abort), 2, stomp, stomp).
+index((stomp_setup), 2, stomp, stomp).
 index((stream_info), 1, stream_info, streaminfo).
 index((add_stream_to_pool), 2, stream_pool, streampool).
 index((delete_stream_from_pool), 1, stream_pool, streampool).
 index((close_stream_pool), 0, stream_pool, streampool).
 index((dispatch_stream_pool), 1, stream_pool, streampool).
 index((stream_pool_main_loop), 0, stream_pool, streampool).
+index((dedent_lines), 3, strings, strings).
+index((indent_lines), 3, strings, strings).
+index((indent_lines), 4, strings, strings).
+index((interpolate_string), 4, strings, strings).
+index((string_lines), 2, strings, strings).
+index((string), 4, strings, strings).
 index((openlog), 3, syslog, syslog).
 index((syslog), 2, syslog, syslog).
 index((syslog), 3, syslog, syslog).
@@ -1180,6 +1304,8 @@ index((prefix_string), 3, table, table).
 index((prefix_string), 4, table, table).
 index((sub_string), 3, table, table).
 index((table_version), 2, table, table).
+index((sort_table), 2, table_util, table_util).
+index((verify_table_order), 1, table_util, table_util).
 index((abolish_all_tables), 0, tables, tables).
 index((abolish_module_tables), 1, tables, tables).
 index((abolish_table_pred), 1, tables, tables).
@@ -1198,8 +1324,6 @@ index((get_returns_for_call), 2, tables, tables).
 index((get_residual), 2, tables, tables).
 index((set_pil_on), 0, tables, tables).
 index((set_pil_off), 0, tables, tables).
-index((sort_table), 2, table_util, table_util).
-index((verify_table_order), 1, table_util, table_util).
 index((term_hash), 2, terms, terms).
 index((term_hash), 4, terms, terms).
 index((term_size), 2, terms, terms).
@@ -1212,6 +1336,14 @@ index((cyclic_term), 1, terms, terms).
 index((acyclic_term), 1, terms, terms).
 index((term_subsumer), 3, terms, terms).
 index((term_factorized), 3, terms, terms).
+index((mapargs), 3, terms, terms).
+index((mapsubterms), 3, terms, terms).
+index((mapsubterms_var), 3, terms, terms).
+index((foldsubterms), 4, terms, terms).
+index((foldsubterms), 5, terms, terms).
+index((same_functor), 2, terms, terms).
+index((same_functor), 3, terms, terms).
+index((same_functor), 4, terms, terms).
 index((show_coverage), 1, prolog_cover, test_cover).
 index((show_coverage), 2, prolog_cover, test_cover).
 index((make_tests), 3, test_wizard, test_wizard).
@@ -1343,12 +1475,17 @@ index((url_iri), 2, url, url).
 index((file_name_to_url), 2, url, url).
 index((set_url_encoding), 2, url, url).
 index((utf8_codes), 3, utf8, utf8).
+index((uuid), 1, uuid, uuid).
+index((uuid), 2, uuid, uuid).
+index((uuid_property), 2, uuid, uuid).
 index((numbervars), 1, varnumbers, varnumbers).
 index((varnumbers), 2, varnumbers, varnumbers).
 index((max_var_number), 3, varnumbers, varnumbers).
 index((varnumbers), 3, varnumbers, varnumbers).
 index((varnumbers_names), 3, varnumbers, varnumbers).
 index((vm_list), 1, prolog_vm, vm).
+index((clause_vm), 2, prolog_vm, vm).
+index((vmi_labels), 2, prolog_vm, vm).
 index((call_residual_program), 2, wfs, wfs).
 index((call_delays), 2, wfs, wfs).
 index((delays_residual_program), 2, wfs, wfs).
